metrics_accuracy module
=======================

This section contains the Python API reference for the
``uncertainty_toolbox.metrics_accuracy`` module, which contains code for metrics
involving accuracy.

uncertainty_toolbox.metrics_accuracy Module
###########################################

.. automodule:: uncertainty_toolbox.metrics_accuracy
    :members:
